@@ -2,11 +2,17 @@ import itertools
 import queue
 import time
 import weakref
-from typing import List
+from typing import List, Any, Tuple
 
 import redis
 
+if redis.VERSION >= (5, 0):
+    from redis.parsers import BaseParser
+else:
+    from redis.connection import BaseParser
+
 from . import _msgs as msgs
+from ._command_args_parsing import extract_args
 from ._commands import (
     Int, Float, SUPPORTED_COMMANDS, COMMANDS_WITH_SUB, key_value_type)
 from ._helpers import (
@@ -14,7 +20,7 @@ from ._helpers import (
     compile_pattern, QUEUED, encode_command)
 
 
-def _extract_command(fields):
+def _extract_command(fields) -> Tuple[Any, List[Any]]:
     cmd = encode_command(fields[0])
     if cmd in COMMANDS_WITH_SUB and len(fields) >= 2:
         cmd += ' ' + encode_command(fields[1])
@@ -27,11 +33,11 @@ def _extract_command(fields):
 class BaseFakeSocket:
     _connection_error_class = redis.ConnectionError
 
-    def __init__(self, server, *args, **kwargs):
+    def __init__(self, server, db, *args, **kwargs):
         super(BaseFakeSocket, self).__init__(*args, **kwargs)
         self._server = server
-        self._db = server.dbs[0]
-        self._db_num = 0
+        self._db_num = db
+        self._db = server.dbs[self._db_num]
         self.responses = queue.Queue()
         # Prevents parser from processing commands. Not used in this module,
         # but set by aioredis module to prevent new commands being processed
@@ -151,7 +157,7 @@ class BaseFakeSocket:
         return result
 
     def _decode_error(self, error):
-        return redis.connection.BaseParser().parse_error(error.value)
+        return BaseParser().parse_error(error.value)
 
     def _decode_result(self, result):
         """Convert SimpleString and SimpleError, recursively"""
@@ -266,22 +272,8 @@ class BaseFakeSocket:
         returned exactly once.
         """
         cursor = int(cursor)
-        pattern = None
-        _type = None
-        count = 10
-        if len(args) % 2 != 0:
-            raise SimpleError(msgs.SYNTAX_ERROR_MSG)
-        for i in range(0, len(args), 2):
-            if casematch(args[i], b'match'):
-                pattern = args[i + 1]
-            elif casematch(args[i], b'count'):
-                count = Int.decode(args[i + 1])
-                if count <= 0:
-                    raise SimpleError(msgs.SYNTAX_ERROR_MSG)
-            elif casematch(args[i], b'type'):
-                _type = args[i + 1]
-            else:
-                raise SimpleError(msgs.SYNTAX_ERROR_MSG)
+        (pattern, _type, count), _ = extract_args(args, ('*match', '*type', '+count'))
+        count = 10 if count is None else count
 
         if cursor >= len(keys):
             return [0, []]
