@@ -30,9 +30,11 @@ class HashCommandsMixin:
     def hgetall(self, key):
         return list(itertools.chain(*key.value.items()))
 
-    @command((Key(Hash), bytes, Int))
+    @command(fixed=(Key(Hash), bytes, bytes))
     def hincrby(self, key, field, amount):
-        c = Int.decode(key.value.get(field, b'0')) + amount
+        amount = Int.decode(amount)
+        field_value = Int.decode(key.value.get(field, b'0'), decode_error=msgs.INVALID_HASH_MSG)
+        c = field_value + amount
         key.value[field] = self._encodeint(c)
         key.updated()
         return c
